"""Command for managing bounces"""

import os
import poplib
import datetime

from django.conf import settings
from django.utils.translation import activate
from django.core.management.base import NoArgsCommand
from django.core.mail import EmailMessage

from jumbo.utils import dsnparser
from jumbo.utils.functions import get_settings

from ticket.models import Ticket
from organization.models import Contact

def send_email(message, body):
    """ send answer emails"""
    email = message.email
    subject = email['Subject']
    body = "%s" % body
    from_email = email["To"].split(" ")[-1].strip("<").strip(">")
    to_email = [email["From"].split(" ")[-1].strip("<").strip(">")]
    email_msg = EmailMessage(subject, body, from_email, [], to_email)
    #email_msg.send(fail_silently=False)

def write_ticket(message):
    """Write info in the db
    :param message: the DSN Message instance
    """
    email = message.email
    submitter = None
    try:
        email_from = email["From"].split(" ")[-1].strip("<").strip(">")
        contact = Contact.objects.get(email=email_from)
        submitter = contact.user
    except Exception, e:
        raise
    try:
        ticket = Ticket()
        ticket.title = email['Subject']
        ticket.description = email['Message']
        ticket.submitter = submitter
        ticket.public = True
        print ticket
    except Exception, e:
        raise

class Command(NoArgsCommand):
    """parse all messages and insert them in tickets"""
    def handle_noargs(self, **options):

        # impostazioni dell'account che riceve l'email/ticket
        host = get_settings("ticket.settings", "TICKET_EMAIL_POP_HOST")
        port = get_settings("ticket.settings", "TICKET_EMAIL_POP_PORT")
        user = get_settings("ticket.settings", "TICKET_EMAIL_POP_USER")
        password = get_settings("ticket.settings", "TICKET_EMAIL_POP_PASSWORD")

        conn = poplib.POP3(host, port)
        conn.user(user)
        conn.pass_(password)

        for msg in conn.list()[1]:
            n, dim = msg.split()
            if not dim:
                continue
            text_msg = "\n".join(conn.retr(n)[1])
            try:
                message = dsnparser.DSNParser(txt=text_msg)
                write_ticket(message)
                send_email(message, "OK")
                #conn.dele(n)
            except Exception, e:
                send_email(message, e)
                continue
        conn.quit()

